16.17. cdist-type__clean_path(7) — cdist 6.1.1 documentation

# 16.17. cdist-type__clean_path(7)

## 16.17.1. NAME

cdist-type__clean_path - Remove files and directories which match the pattern.

## 16.17.2. DESCRIPTION

Remove files and directories which match the pattern.

Provided path (as __object_id) must be a directory.

Patterns are passed to `find`'s `-regex` - see `find(1)` for more details.

Look up of files and directories is non-recursive (`-maxdepth 1`).

Parent directory is excluded (`-mindepth 1`).

This type is not POSIX compatible (sorry, Solaris users).

## 16.17.3. REQUIRED PARAMETERS

pattern
  Pattern of files which are removed from path.

## 16.17.4. OPTIONAL PARAMETERS

exclude
  Pattern of files which are excluded from removal.
onchange
  The code to run if files or directories were removed.

## 16.17.5. EXAMPLES

    __clean_path /etc/apache2/conf-enabled \
        --pattern '.+' \
        --exclude '.+\(charset\.conf\|security\.conf\)' \
        --onchange 'service apache2 restart'

## 16.17.6. AUTHORS

Ander Punnar <ander-at-kvlt-dot-ee>

## 16.17.7. COPYING

Copyright (C) 2019 Ander Punnar. You can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.